

set -ex



test -f $PREFIX/lib/gstreamer-1.0/libgstalpha${SHLIB_EXT}
test -f $PREFIX/lib/gstreamer-1.0/libgstdebug${SHLIB_EXT}
test -f $PREFIX/lib/gstreamer-1.0/libgstspectrum${SHLIB_EXT}
gst-inspect-1.0 --plugin alpha
exit 0
